@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2007  Salvo "LtWorf" Tomaselli
+Copyright (C) 2017  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -39,7 +39,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <sys/un.h>
 #include <errno.h>
 
-
 #include "utils.h"
 #include "myio.h"
 #include "cgi.h"
@@ -63,7 +62,6 @@ extern int indexes_l;                       //Length of array
 extern pthread_key_t thread_key;            //key for pthread_setspecific
 
 
-
 int request_auth(connection_t *connection_prop);
 void piperr();
 int write_dir(char *real_basedir, connection_t * connection_prop);
@@ -138,7 +136,6 @@ static inline void handle_requests(char* buf,buffered_read_t * read_b,int * bufF
     int sock=connection_prop->sock;
     char *lasts;//Used by strtok_r
 
-
     short int r;//Readed char
     char *end;//Pointer to header's end
 
@@ -217,7 +214,13 @@ static inline void handle_requests(char* buf,buffered_read_t * read_b,int * bufF
         }
 
 #ifdef REQUESTDBG
-        syslog(LOG_INFO,"%s - %d - %s %s",connection_prop->ip_addr,connection_prop->status_code,connection_prop->method,connection_prop->page);
+        syslog(LOG_INFO,
+               "%s - %d - %s %s",
+               connection_prop->ip_addr,
+               connection_prop->status_code,
+               connection_prop->method,
+               connection_prop->page
+              );
 #endif
 
 
@@ -227,7 +230,10 @@ static inline void handle_requests(char* buf,buffered_read_t * read_b,int * bufF
     } /* while */
 
 bad_request:
-    send_err(connection_prop,400,"Bad request");
+    send_error_header(400, connection_prop);
+#ifdef REQUESTDBG
+    syslog(LOG_INFO, "%s - %d", connection_prop->ip_addr, connection_prop->status_code);
+#endif
     close(sock);
     return;
 }
@@ -381,11 +387,14 @@ int read_file(connection_t* connection_prop,buffered_read_t* read_b) {
     }
 
     int fd=open(connection_prop->strfile,O_WRONLY|O_CREAT,S_IRUSR|S_IWUSR);
-    if (fd<0) {
+    if (fd == -1) {
         return ERR_FILENOTFOUND;
     }
 
-    ftruncate(fd,content_l);
+    if (ftruncate(fd, content_l) == -1) {
+        close(fd);
+        return ERR_NOMEM;
+    }
 
     char* buf=malloc(FILEBUF);//Buffer to read from file
     if (buf==NULL) {
@@ -405,11 +414,11 @@ int read_file(connection_t* connection_prop,buffered_read_t* read_b) {
         write_=write(fd,buf,read_);
 
         if (write_!=read_) {
-            retval= ERR_BRKPIPE;
+            retval = ERR_BRKPIPE;
             break;
         }
 
-        tot_read+=read_;
+        tot_read += read_;
     }
 
     free(buf);
@@ -475,26 +484,25 @@ http_param is a string containing parameters of the HTTP request
 static int send_page(buffered_read_t* read_b, connection_t* connection_prop) {
     int retval=0;//Return value after sending the page
     string_t post_param; //Contains POST data
+    post_param.data = NULL;
+    post_param.len = 0;
 
 #ifdef SENDINGDBG
     syslog (LOG_DEBUG,"URL changed into %s",connection_prop->page);
 #endif
 
-    if (auth_check_request(connection_prop)!=0) { //If auth is required
+    if (auth_check_request(connection_prop) != 0) { //If auth is required
+        read_post_data(connection_prop, read_b); //Consume request body
         retval = ERR_NOAUTH;
-        post_param.data=NULL;
         goto escape;
     }
 
     connection_prop->strfile_len = snprintf(connection_prop->strfile,URI_LEN,"%s%s",connection_prop->basedir,connection_prop->page);//Prepares the string
 
     if (connection_prop->method_id>=PUT) {//Methods from PUT to other uncommon ones :-D
-        post_param.data=NULL;
-        post_param.len=0;
-
         switch (connection_prop->method_id) {
         case PUT:
-            retval=read_file(connection_prop,read_b);
+            retval=read_file(connection_prop, read_b);
             break;
         case DELETE:
             retval=delete_file(connection_prop);
@@ -505,36 +513,33 @@ static int send_page(buffered_read_t* read_b, connection_t* connection_prop) {
 #ifdef WEBDAV
         case PROPFIND:
             //Propfind has data, not strictly post but read_post_data will work
-            post_param=read_post_data(connection_prop,read_b);
-            retval=propfind(connection_prop,&post_param);
+            post_param = read_post_data(connection_prop, read_b);
+            retval = propfind(connection_prop, &post_param);
             break;
         case MKCOL:
-            retval=mkcol(connection_prop);
+            retval = mkcol(connection_prop);
             break;
         case COPY:
         case MOVE:
-            retval=copy_move(connection_prop);
+            retval = copy_move(connection_prop);
             break;
 #endif
         }
-
         goto escape;
     }
 
     if (connection_prop->method_id==POST)
-        post_param=read_post_data(connection_prop,read_b);
-    else
-        post_param.data=NULL;
+        post_param = read_post_data(connection_prop,read_b);
 
     if ((connection_prop->strfile_fd=open(connection_prop->strfile,O_RDONLY | O_LARGEFILE))<0) {
         //File doesn't exist. Must return errorcode
-        retval=ERR_FILENOTFOUND;
+        retval = ERR_FILENOTFOUND;
         goto escape;
     }
 
     fstat(connection_prop->strfile_fd, &connection_prop->strfile_stat);
 
-    retval = get_or_post(connection_prop,post_param);
+    retval = get_or_post(connection_prop, post_param);
 
 escape:
     free(post_param.data);
@@ -544,7 +549,7 @@ escape:
         close(connection_prop->strfile_fd);
     }
 
-    return send_error_header(retval,connection_prop);
+    return send_error_header(retval, connection_prop);
 }
 
 /**
@@ -602,10 +607,7 @@ static int get_or_post(connection_t *connection_prop, string_t post_param) {
 
         //send normal file, control reaches this point if scripts are disabled or if the filename doesn't trigger CGI
         return write_file(connection_prop);
-
-
     }
-    //return 0; //make gcc happy
 }
 
 /**
@@ -648,7 +650,6 @@ static int send_error_header(int retval, connection_t *connection_prop) {
         return send_http_header(201,0,NULL,true,-1,connection_prop);
     }
     return 0; //Make gcc happy
-
 }
 
 /**
@@ -730,10 +731,10 @@ int write_dir(char* real_basedir,connection_t* connection_prop) {
             connection_prop->strfile_stat.st_mtime,
             connection_prop
         );
-        write(sock,html,pagelen);
+        write(sock, html, pagelen);
 
         //Write item in cache
-        cache_store_item(0,connection_prop,html,pagelen);
+        cache_store_item(0, connection_prop, html, pagelen);
     }
 
     free(html);//Frees the memory used for the page
@@ -985,10 +986,10 @@ int request_auth(connection_t *connection_prop) {
 /**
 Sends an error to the client
 */
-int send_err(connection_t *connection_prop,int err,char* descr) {
+int send_err(connection_t *connection_prop, int err, char* descr) {
     int sock=connection_prop->sock;
 
-    connection_prop->status_code=err; //Sets status code, for the logs
+    connection_prop->status_code = err; //Sets status code, for the logs
 
     //Buffer for both header and page
     char * head=malloc(MAXSCRIPTOUT+HEADBUF);
@@ -1029,7 +1030,7 @@ This function reads post data and returns the pointer to the buffer containing t
 or NULL if there was no data.
 If it doesn't return a null value, the returned pointer must be freed.
 */
-string_t read_post_data(connection_t* connection_prop,buffered_read_t* read_b) {
+string_t read_post_data(connection_t* connection_prop, buffered_read_t* read_b) {
     int sock=connection_prop->sock;
     string_t res;
     res.len=0;
@@ -1039,11 +1040,10 @@ string_t read_post_data(connection_t* connection_prop,buffered_read_t* read_b) {
     char a[NBUFFER];
     //Gets the value
     char *content_length="Content-Length";
-    bool r=get_param_value(connection_prop->http_param,content_length, a,NBUFFER,strlen(content_length));
 
-    //If there is a value and method is POST
-    if (r!=false) { //&& connection_prop->method_id==POST) {
-        long int l=strtol( a , NULL, 0 );
+    //If there is a request body
+    if (get_param_value(connection_prop->http_param, content_length, a, NBUFFER, strlen(content_length))) {
+        long int l = strtol(a, NULL, 0 );
         if (l<=POST_MAX_SIZE && (res.data=malloc(l))!=NULL) {//Post size is ok and buffer is allocated
             res.len=buffer_read(sock,res.data,l,read_b);
         }
@@ -1083,7 +1083,7 @@ This function returns the reason phrase according to the response
 code.
 */
 static inline char *reason_phrase(int code) {
-    code=code/100;
+    code /= 100;
 
     switch (code) {
     case 2:
@@ -1096,7 +1096,6 @@ static inline char *reason_phrase(int code) {
         return "Server error";
     case 1:
         return "Received";
-
     };
     return "Something is very wrong";
 }
@@ -1234,12 +1233,23 @@ static int tar_send_dir(connection_t* connection_prop) {
 
     if (pid==0) { //child, executing tar
         fclose (stdout); //Closing the stdout
-        dup(connection_prop->sock); //Redirects the stdout
-        nice(1); //Reducing priority
+        if (dup(connection_prop->sock) == -1) { //Redirects the stdout
+            exit(1);
+        }
+        errno = 0;
+        if (nice(1) == -1 && errno != 0) {
+            //Failed to reduce priority
+            syslog(LOG_INFO, "Failed to nice() child process");
+        }
         execlp("tar","tar","-cz",connection_prop->strfile,(char *)0);
+        exit(1);
     } else if (pid>0) { //Father, does nothing
         int status;
-        waitpid(pid,&status,0);
+        waitpid(pid, &status, 0);
+        if (status != 0) {
+            syslog(LOG_ERR, "tar terminated with exit code %d", status);
+            return ERR_BRKPIPE;
+        }
     } else { //Error
         return ERR_NOMEM; //Well not enough memory in process table...
     }
