@@ -20,6 +20,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "options.h"
 
+#include <string.h>
+#include <stdlib.h>
+#include <stdbool.h>
+#include <ctype.h>
+
 #include "mystring.h"
 
 /**
@@ -37,33 +42,17 @@ This function splits the page name from the GET params.
 It also sets the value for the page_len field
 */
 void split_get_params(connection_t* connection_prop) {
-    int i=0;
-    connection_prop->get_params=NULL;
-    while (connection_prop->page[i]!=0) {
-        if (connection_prop->page[i]=='?') {
-            connection_prop->page[i]=0;
-            connection_prop->get_params=&connection_prop->page[i+1];
-            break;
-        }
-        i++;
-    }
-    connection_prop->page_len=i;
-}
-/*void split_get_params(connection_t* connection_prop) {
     char *separator=strstr(connection_prop->page,"?");
 
     if (separator==NULL) {
         connection_prop->get_params=NULL;
         connection_prop->page_len=strlen(connection_prop->page);
-
     } else {
-
         separator[0]=0;
         connection_prop->get_params=separator+1;
         connection_prop->page_len=separator-connection_prop->page;
-
     }
-}*/
+}
 
 
 /**
@@ -139,6 +128,6 @@ size of end
 If str ends with end, true is returned
 false otherwise
 */
-bool endsWith(char *str, char *end,ssize_t len_str,ssize_t len_end) {
+bool endsWith(char *str, char *end, size_t len_str, size_t len_end) {
     return strcmp(str+len_str-len_end,end)==0;
 }
