@@ -35,7 +35,7 @@ class weborf_runner():
         self.socket = None
         self.listener = None
         self.waiter = None
-        self.methods = []
+        self.methods = set()
         self.username = None
         self.password = None
         self.ipv6 = True
@@ -108,17 +108,15 @@ class weborf_runner():
         # Deciding which HTTP methods will be enabled
         self.methods = {'GET'}
         if options['dav']:
-            self.methods = self.methods.union({'OPTIONS', 'PROPFIND'})
+            self.methods.update({'OPTIONS', 'PROPFIND'})
             self.logclass.logger(
                 "DAV access enabled", self.logclass.DBG_NOTICE)
 
             # If writing is enabled
             if options['write']:
-                self.methods = self.methods.union(
-                    {'PUT', 'DELETE', 'COPY', 'MOVE', 'MKCOL'})
+                self.methods.update({'PUT', 'DELETE', 'COPY', 'MOVE', 'MKCOL'})
                 self.logclass.logger(
-                    'Writing access enabled. This could pose security threat', self.logclass.DBG_WARNING)
-
+                    'Writing access enabled.', self.logclass.DBG_WARNING)
         return True
 
     def __create_auth_socket(self):
@@ -187,13 +185,12 @@ class weborf_runner():
             cmdline.append(options['ip'])
         self.logclass.logger(' '.join(cmdline))
 
-        self.child = subprocess.Popen(
-            cmdline, bufsize=1024, stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+        self.child = subprocess.Popen(cmdline)
 
         self.loglinks(options)
 
-        self.waiter = __waiter__(
-            self.child)  # Starts thread to wait for weborf termination
+        # Starts thread to wait for weborf termination
+        self.waiter = __waiter__(self.child)
 
         self.waiter.child_terminated.connect(self._child_terminated)
         self.waiter.start()
@@ -252,7 +249,6 @@ class weborf_runner():
         if self._running:
             self.logclass.logger(
                 "Sending terminate signal and waiting for termination...")
-            self.child.stdin.close()
             self.child.terminate()
 
         self.socket.close()
